Enum Argument
#[non_exhaustive]pub enum Argument {
Gas,
Input(u16),
Result(u16),
NestedResult(u16, u16),
}Expand description
An argument to a programmable transaction command
BCS
The BCS serialized form for this type is defined by the following ABNF:
argument = argument-gas
=/ argument-input
=/ argument-result
=/ argument-nested-result
argument-gas = %d00
argument-input = %d01 u16
argument-result = %d02 u16
argument-nested-result = %d03 u16 u16Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Gas
The gas coin. The gas coin can only be used by-ref, except for with
TransferObjects, which can use it by-value.
Input(u16)
One of the input objects or primitive values (from
ProgrammableTransaction inputs)
Result(u16)
The result of another command (from ProgrammableTransaction commands)
NestedResult(u16, u16)
Like a Result but it accesses a nested result. Currently, the only
usage of this is to access a value from a Move call with multiple
return values.
Implementations
impl Argument
impl Argument
pub fn is_nested_result(&self) -> bool
pub fn is_nested_result(&self) -> bool
Checks if this is a nested_result variant.
pub fn as_input_opt(&self) -> Option<u16>
pub fn as_input(&self) -> u16
pub fn as_result_opt(&self) -> Option<u16>
pub fn as_result(&self) -> u16
pub fn as_nested_result_opt(&self) -> Option<(u16, u16)>
pub fn as_nested_result(&self) -> (u16, u16)
pub fn get_nested_result(&self, ix: u16) -> Option<Argument>
pub fn get_nested_result(&self, ix: u16) -> Option<Argument>
Get the nested result for this result at the given index. Returns None if this is not a Result.