Enum EndOfEpochTransactionKind
#[non_exhaustive]pub enum EndOfEpochTransactionKind {
ChangeEpoch(ChangeEpoch),
ChangeEpochV2(ChangeEpochV2),
ChangeEpochV3(ChangeEpochV3),
ChangeEpochV4(ChangeEpochV4),
}Expand description
Operation run at the end of an epoch
BCS
The BCS serialized form for this type is defined by the following ABNF:
end-of-epoch-transaction-kind = %d00 change-epoch ; ChangeEpoch
=/ %d01 change-epoch-v2 ; ChangeEpochV2
=/ %d02 change-epoch-v3 ; ChangeEpochV3
=/ %d03 change-epoch-v4 ; ChangeEpochV4Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ChangeEpoch(ChangeEpoch)
End the epoch and start the next one
ChangeEpochV2(ChangeEpochV2)
End the epoch and start the next one
ChangeEpochV3(ChangeEpochV3)
End the epoch and start the next one
ChangeEpochV4(ChangeEpochV4)
End the epoch and start the next one
Implementations
impl EndOfEpochTransactionKind
impl EndOfEpochTransactionKind
pub fn is_change_epoch(&self) -> bool
pub fn is_change_epoch(&self) -> bool
Checks if this is a change_epoch variant.
pub fn as_change_epoch(&self) -> &ChangeEpoch
pub fn as_change_epoch(&self) -> &ChangeEpoch
Converts this into a change_epoch if it is a change_epoch variant, or panics otherwise.
pub fn as_change_epoch_mut(&mut self) -> &mut ChangeEpoch
pub fn as_change_epoch_mut(&mut self) -> &mut ChangeEpoch
Converts this into a mut change_epoch if it is a change_epoch variant, or panics otherwise.
pub fn as_change_epoch_opt(&self) -> Option<&ChangeEpoch>
pub fn as_change_epoch_opt(&self) -> Option<&ChangeEpoch>
Converts this into a change_epoch if it is a change_epoch variant, or returns None otherwise.
pub fn as_change_epoch_mut_opt(&mut self) -> Option<&mut ChangeEpoch>
pub fn as_change_epoch_mut_opt(&mut self) -> Option<&mut ChangeEpoch>
Converts this into a mut change_epoch if it is a change_epoch variant, or returns None otherwise.
pub fn into_change_epoch_opt(self) -> Option<ChangeEpoch>
pub fn into_change_epoch_opt(self) -> Option<ChangeEpoch>
Converts this into a change_epoch if it is a change_epoch variant, or returns None otherwise.
pub fn into_change_epoch(self) -> ChangeEpoch
pub fn into_change_epoch(self) -> ChangeEpoch
Converts this into a change_epoch if it is a change_epoch variant, or panics otherwise.
pub fn is_change_epoch_v2(&self) -> bool
pub fn is_change_epoch_v2(&self) -> bool
Checks if this is a change_epoch_v2 variant.
pub fn as_change_epoch_v2(&self) -> &ChangeEpochV2
pub fn as_change_epoch_v2(&self) -> &ChangeEpochV2
Converts this into a change_epoch_v2 if it is a change_epoch_v2 variant, or panics otherwise.
pub fn as_change_epoch_v2_mut(&mut self) -> &mut ChangeEpochV2
pub fn as_change_epoch_v2_mut(&mut self) -> &mut ChangeEpochV2
Converts this into a mut change_epoch_v2 if it is a change_epoch_v2 variant, or panics otherwise.
pub fn as_change_epoch_v2_opt(&self) -> Option<&ChangeEpochV2>
pub fn as_change_epoch_v2_opt(&self) -> Option<&ChangeEpochV2>
Converts this into a change_epoch_v2 if it is a change_epoch_v2 variant, or returns None otherwise.
pub fn as_change_epoch_v2_mut_opt(&mut self) -> Option<&mut ChangeEpochV2>
pub fn as_change_epoch_v2_mut_opt(&mut self) -> Option<&mut ChangeEpochV2>
Converts this into a mut change_epoch_v2 if it is a change_epoch_v2 variant, or returns None otherwise.
pub fn into_change_epoch_v2_opt(self) -> Option<ChangeEpochV2>
pub fn into_change_epoch_v2_opt(self) -> Option<ChangeEpochV2>
Converts this into a change_epoch_v2 if it is a change_epoch_v2 variant, or returns None otherwise.
pub fn into_change_epoch_v2(self) -> ChangeEpochV2
pub fn into_change_epoch_v2(self) -> ChangeEpochV2
Converts this into a change_epoch_v2 if it is a change_epoch_v2 variant, or panics otherwise.
pub fn is_change_epoch_v3(&self) -> bool
pub fn is_change_epoch_v3(&self) -> bool
Checks if this is a change_epoch_v3 variant.
pub fn as_change_epoch_v3(&self) -> &ChangeEpochV3
pub fn as_change_epoch_v3(&self) -> &ChangeEpochV3
Converts this into a change_epoch_v3 if it is a change_epoch_v3 variant, or panics otherwise.
pub fn as_change_epoch_v3_mut(&mut self) -> &mut ChangeEpochV3
pub fn as_change_epoch_v3_mut(&mut self) -> &mut ChangeEpochV3
Converts this into a mut change_epoch_v3 if it is a change_epoch_v3 variant, or panics otherwise.
pub fn as_change_epoch_v3_opt(&self) -> Option<&ChangeEpochV3>
pub fn as_change_epoch_v3_opt(&self) -> Option<&ChangeEpochV3>
Converts this into a change_epoch_v3 if it is a change_epoch_v3 variant, or returns None otherwise.
pub fn as_change_epoch_v3_mut_opt(&mut self) -> Option<&mut ChangeEpochV3>
pub fn as_change_epoch_v3_mut_opt(&mut self) -> Option<&mut ChangeEpochV3>
Converts this into a mut change_epoch_v3 if it is a change_epoch_v3 variant, or returns None otherwise.
pub fn into_change_epoch_v3_opt(self) -> Option<ChangeEpochV3>
pub fn into_change_epoch_v3_opt(self) -> Option<ChangeEpochV3>
Converts this into a change_epoch_v3 if it is a change_epoch_v3 variant, or returns None otherwise.
pub fn into_change_epoch_v3(self) -> ChangeEpochV3
pub fn into_change_epoch_v3(self) -> ChangeEpochV3
Converts this into a change_epoch_v3 if it is a change_epoch_v3 variant, or panics otherwise.
pub fn is_change_epoch_v4(&self) -> bool
pub fn is_change_epoch_v4(&self) -> bool
Checks if this is a change_epoch_v4 variant.
pub fn as_change_epoch_v4(&self) -> &ChangeEpochV4
pub fn as_change_epoch_v4(&self) -> &ChangeEpochV4
Converts this into a change_epoch_v4 if it is a change_epoch_v4 variant, or panics otherwise.
pub fn as_change_epoch_v4_mut(&mut self) -> &mut ChangeEpochV4
pub fn as_change_epoch_v4_mut(&mut self) -> &mut ChangeEpochV4
Converts this into a mut change_epoch_v4 if it is a change_epoch_v4 variant, or panics otherwise.
pub fn as_change_epoch_v4_opt(&self) -> Option<&ChangeEpochV4>
pub fn as_change_epoch_v4_opt(&self) -> Option<&ChangeEpochV4>
Converts this into a change_epoch_v4 if it is a change_epoch_v4 variant, or returns None otherwise.
pub fn as_change_epoch_v4_mut_opt(&mut self) -> Option<&mut ChangeEpochV4>
pub fn as_change_epoch_v4_mut_opt(&mut self) -> Option<&mut ChangeEpochV4>
Converts this into a mut change_epoch_v4 if it is a change_epoch_v4 variant, or returns None otherwise.
pub fn into_change_epoch_v4_opt(self) -> Option<ChangeEpochV4>
pub fn into_change_epoch_v4_opt(self) -> Option<ChangeEpochV4>
Converts this into a change_epoch_v4 if it is a change_epoch_v4 variant, or returns None otherwise.
pub fn into_change_epoch_v4(self) -> ChangeEpochV4
pub fn into_change_epoch_v4(self) -> ChangeEpochV4
Converts this into a change_epoch_v4 if it is a change_epoch_v4 variant, or panics otherwise.
pub fn new_change_epoch(
next_epoch: u64,
protocol_version: u64,
storage_charge: u64,
computation_charge: u64,
storage_rebate: u64,
non_refundable_storage_fee: u64,
epoch_start_timestamp_ms: u64,
system_packages: Vec<SystemPackage>,
) -> EndOfEpochTransactionKind
pub fn new_change_epoch( next_epoch: u64, protocol_version: u64, storage_charge: u64, computation_charge: u64, storage_rebate: u64, non_refundable_storage_fee: u64, epoch_start_timestamp_ms: u64, system_packages: Vec<SystemPackage>, ) -> EndOfEpochTransactionKind
Creates a ChangeEpoch end-of-epoch transaction kind.
pub fn new_change_epoch_v2(
next_epoch: u64,
protocol_version: u64,
storage_charge: u64,
computation_charge: u64,
computation_charge_burned: u64,
storage_rebate: u64,
non_refundable_storage_fee: u64,
epoch_start_timestamp_ms: u64,
system_packages: Vec<SystemPackage>,
) -> EndOfEpochTransactionKind
pub fn new_change_epoch_v2( next_epoch: u64, protocol_version: u64, storage_charge: u64, computation_charge: u64, computation_charge_burned: u64, storage_rebate: u64, non_refundable_storage_fee: u64, epoch_start_timestamp_ms: u64, system_packages: Vec<SystemPackage>, ) -> EndOfEpochTransactionKind
Creates a ChangeEpochV2 end-of-epoch transaction kind.
pub fn new_change_epoch_v3(
next_epoch: u64,
protocol_version: u64,
storage_charge: u64,
computation_charge: u64,
computation_charge_burned: u64,
storage_rebate: u64,
non_refundable_storage_fee: u64,
epoch_start_timestamp_ms: u64,
system_packages: Vec<SystemPackage>,
eligible_active_validators: Vec<u64>,
) -> EndOfEpochTransactionKind
pub fn new_change_epoch_v3( next_epoch: u64, protocol_version: u64, storage_charge: u64, computation_charge: u64, computation_charge_burned: u64, storage_rebate: u64, non_refundable_storage_fee: u64, epoch_start_timestamp_ms: u64, system_packages: Vec<SystemPackage>, eligible_active_validators: Vec<u64>, ) -> EndOfEpochTransactionKind
Creates a ChangeEpochV3 end-of-epoch transaction kind.
pub fn new_change_epoch_v4(
next_epoch: u64,
protocol_version: u64,
storage_charge: u64,
computation_charge: u64,
computation_charge_burned: u64,
storage_rebate: u64,
non_refundable_storage_fee: u64,
epoch_start_timestamp_ms: u64,
system_packages: Vec<SystemPackage>,
eligible_active_validators: Vec<u64>,
scores: Vec<u64>,
adjust_rewards_by_score: bool,
) -> EndOfEpochTransactionKind
pub fn new_change_epoch_v4( next_epoch: u64, protocol_version: u64, storage_charge: u64, computation_charge: u64, computation_charge_burned: u64, storage_rebate: u64, non_refundable_storage_fee: u64, epoch_start_timestamp_ms: u64, system_packages: Vec<SystemPackage>, eligible_active_validators: Vec<u64>, scores: Vec<u64>, adjust_rewards_by_score: bool, ) -> EndOfEpochTransactionKind
Creates a ChangeEpochV4 end-of-epoch transaction kind.
Returns an iterator over the shared input objects required by this transaction kind.