Enum TransactionExpiration
#[non_exhaustive]pub enum TransactionExpiration {
None,
Epoch(u64),
}Expand description
A TTL for a transaction
BCS
The BCS serialized form for this type is defined by the following ABNF:
transaction-expiration = %d00 ; none
=/ %d01 u64 ; epochVariants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
The transaction has no expiration
Epoch(u64)
Validators won’t sign a transaction unless the expiration Epoch is greater than or equal to the current epoch
Implementations
impl TransactionExpiration
impl TransactionExpiration
pub fn as_epoch(&self) -> &u64
pub fn as_epoch(&self) -> &u64
Converts this into a epoch if it is a epoch variant, or panics otherwise.
pub fn as_epoch_mut(&mut self) -> &mut u64
pub fn as_epoch_mut(&mut self) -> &mut u64
Converts this into a mut epoch if it is a epoch variant, or panics otherwise.
pub fn as_epoch_opt(&self) -> Option<&u64>
pub fn as_epoch_opt(&self) -> Option<&u64>
Converts this into a epoch if it is a epoch variant, or returns None otherwise.
pub fn as_epoch_mut_opt(&mut self) -> Option<&mut u64>
pub fn as_epoch_mut_opt(&mut self) -> Option<&mut u64>
Converts this into a mut epoch if it is a epoch variant, or returns None otherwise.
pub fn into_epoch_opt(self) -> Option<u64>
pub fn into_epoch_opt(self) -> Option<u64>
Converts this into a epoch if it is a epoch variant, or returns None otherwise.
pub fn into_epoch(self) -> u64
pub fn into_epoch(self) -> u64
Converts this into a epoch if it is a epoch variant, or panics otherwise.