Enum TransactionKind
#[non_exhaustive]pub enum TransactionKind {
Programmable(ProgrammableTransaction),
Genesis(GenesisTransaction),
ConsensusCommitPrologueV1(ConsensusCommitPrologueV1),
AuthenticatorStateUpdateV1Deprecated,
EndOfEpoch(Vec<EndOfEpochTransactionKind>),
RandomnessStateUpdate(RandomnessStateUpdate),
}Expand description
Transaction type
BCS
The BCS serialized form for this type is defined by the following ABNF:
transaction-kind = %d00 programmable-transaction ; Programmable
=/ %d01 genesis-transaction ; Genesis
=/ %d02 consensus-commit-prologue-v1 ; ConsensusCommitPrologueV1
=/ %d03 ; AuthenticatorStateUpdateV1Deprecated
=/ %d04 (vector end-of-epoch-transaction-kind) ; EndOfEpoch
=/ %d05 randomness-state-update ; RandomnessStateUpdateVariants (Non-exhaustive)
This enum is marked as non-exhaustive
Programmable(ProgrammableTransaction)
A user transaction comprised of a list of native commands and move calls
Genesis(GenesisTransaction)
Transaction used to initialize the chain state.
Only valid if in the genesis checkpoint (0) and if this is the very first transaction ever executed on the chain.
ConsensusCommitPrologueV1(ConsensusCommitPrologueV1)
V1 consensus commit update
AuthenticatorStateUpdateV1Deprecated
Update set of valid JWKs used for zklogin - Deprecated
EndOfEpoch(Vec<EndOfEpochTransactionKind>)
Set of operations to run at the end of the epoch to close out the current epoch and start the next one.
RandomnessStateUpdate(RandomnessStateUpdate)
Randomness update
Implementations
impl TransactionKind
impl TransactionKind
pub fn is_consensus_commit_prologue_v1(&self) -> bool
pub fn is_consensus_commit_prologue_v1(&self) -> bool
Checks if this is a consensus_commit_prologue_v1 variant.
pub fn as_consensus_commit_prologue_v1(&self) -> &ConsensusCommitPrologueV1
pub fn as_consensus_commit_prologue_v1(&self) -> &ConsensusCommitPrologueV1
Converts this into a consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or panics otherwise.
pub fn as_consensus_commit_prologue_v1_mut(
&mut self,
) -> &mut ConsensusCommitPrologueV1
pub fn as_consensus_commit_prologue_v1_mut( &mut self, ) -> &mut ConsensusCommitPrologueV1
Converts this into a mut consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or panics otherwise.
pub fn as_consensus_commit_prologue_v1_opt(
&self,
) -> Option<&ConsensusCommitPrologueV1>
pub fn as_consensus_commit_prologue_v1_opt( &self, ) -> Option<&ConsensusCommitPrologueV1>
Converts this into a consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or returns None otherwise.
pub fn as_consensus_commit_prologue_v1_mut_opt(
&mut self,
) -> Option<&mut ConsensusCommitPrologueV1>
pub fn as_consensus_commit_prologue_v1_mut_opt( &mut self, ) -> Option<&mut ConsensusCommitPrologueV1>
Converts this into a mut consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or returns None otherwise.
pub fn into_consensus_commit_prologue_v1_opt(
self,
) -> Option<ConsensusCommitPrologueV1>
pub fn into_consensus_commit_prologue_v1_opt( self, ) -> Option<ConsensusCommitPrologueV1>
Converts this into a consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or returns None otherwise.
pub fn into_consensus_commit_prologue_v1(self) -> ConsensusCommitPrologueV1
pub fn into_consensus_commit_prologue_v1(self) -> ConsensusCommitPrologueV1
Converts this into a consensus_commit_prologue_v1 if it is a consensus_commit_prologue_v1 variant, or panics otherwise.
pub fn is_randomness_state_update(&self) -> bool
pub fn is_randomness_state_update(&self) -> bool
Checks if this is a randomness_state_update variant.
pub fn as_randomness_state_update(&self) -> &RandomnessStateUpdate
pub fn as_randomness_state_update(&self) -> &RandomnessStateUpdate
Converts this into a randomness_state_update if it is a randomness_state_update variant, or panics otherwise.
pub fn as_randomness_state_update_mut(&mut self) -> &mut RandomnessStateUpdate
pub fn as_randomness_state_update_mut(&mut self) -> &mut RandomnessStateUpdate
Converts this into a mut randomness_state_update if it is a randomness_state_update variant, or panics otherwise.
pub fn as_randomness_state_update_opt(&self) -> Option<&RandomnessStateUpdate>
pub fn as_randomness_state_update_opt(&self) -> Option<&RandomnessStateUpdate>
Converts this into a randomness_state_update if it is a randomness_state_update variant, or returns None otherwise.
pub fn as_randomness_state_update_mut_opt(
&mut self,
) -> Option<&mut RandomnessStateUpdate>
pub fn as_randomness_state_update_mut_opt( &mut self, ) -> Option<&mut RandomnessStateUpdate>
Converts this into a mut randomness_state_update if it is a randomness_state_update variant, or returns None otherwise.
pub fn into_randomness_state_update_opt(self) -> Option<RandomnessStateUpdate>
pub fn into_randomness_state_update_opt(self) -> Option<RandomnessStateUpdate>
Converts this into a randomness_state_update if it is a randomness_state_update variant, or returns None otherwise.
pub fn into_randomness_state_update(self) -> RandomnessStateUpdate
pub fn into_randomness_state_update(self) -> RandomnessStateUpdate
Converts this into a randomness_state_update if it is a randomness_state_update variant, or panics otherwise.
pub fn is_programmable(&self) -> bool
pub fn is_programmable(&self) -> bool
Checks if this is a programmable variant.
pub fn as_programmable(&self) -> &ProgrammableTransaction
pub fn as_programmable(&self) -> &ProgrammableTransaction
Converts this into a programmable if it is a programmable variant, or panics otherwise.
pub fn as_programmable_mut(&mut self) -> &mut ProgrammableTransaction
pub fn as_programmable_mut(&mut self) -> &mut ProgrammableTransaction
Converts this into a mut programmable if it is a programmable variant, or panics otherwise.
pub fn as_programmable_opt(&self) -> Option<&ProgrammableTransaction>
pub fn as_programmable_opt(&self) -> Option<&ProgrammableTransaction>
Converts this into a programmable if it is a programmable variant, or returns None otherwise.
pub fn as_programmable_mut_opt(
&mut self,
) -> Option<&mut ProgrammableTransaction>
pub fn as_programmable_mut_opt( &mut self, ) -> Option<&mut ProgrammableTransaction>
Converts this into a mut programmable if it is a programmable variant, or returns None otherwise.
pub fn into_programmable_opt(self) -> Option<ProgrammableTransaction>
pub fn into_programmable_opt(self) -> Option<ProgrammableTransaction>
Converts this into a programmable if it is a programmable variant, or returns None otherwise.
pub fn into_programmable(self) -> ProgrammableTransaction
pub fn into_programmable(self) -> ProgrammableTransaction
Converts this into a programmable if it is a programmable variant, or panics otherwise.
pub fn is_genesis(&self) -> bool
pub fn is_genesis(&self) -> bool
Checks if this is a genesis variant.
pub fn as_genesis(&self) -> &GenesisTransaction
pub fn as_genesis(&self) -> &GenesisTransaction
Converts this into a genesis if it is a genesis variant, or panics otherwise.
pub fn as_genesis_mut(&mut self) -> &mut GenesisTransaction
pub fn as_genesis_mut(&mut self) -> &mut GenesisTransaction
Converts this into a mut genesis if it is a genesis variant, or panics otherwise.
pub fn as_genesis_opt(&self) -> Option<&GenesisTransaction>
pub fn as_genesis_opt(&self) -> Option<&GenesisTransaction>
Converts this into a genesis if it is a genesis variant, or returns None otherwise.
pub fn as_genesis_mut_opt(&mut self) -> Option<&mut GenesisTransaction>
pub fn as_genesis_mut_opt(&mut self) -> Option<&mut GenesisTransaction>
Converts this into a mut genesis if it is a genesis variant, or returns None otherwise.
pub fn into_genesis_opt(self) -> Option<GenesisTransaction>
pub fn into_genesis_opt(self) -> Option<GenesisTransaction>
Converts this into a genesis if it is a genesis variant, or returns None otherwise.
pub fn into_genesis(self) -> GenesisTransaction
pub fn into_genesis(self) -> GenesisTransaction
Converts this into a genesis if it is a genesis variant, or panics otherwise.
pub fn is_end_of_epoch(&self) -> bool
pub fn is_end_of_epoch(&self) -> bool
Checks if this is a end_of_epoch variant.
pub fn as_end_of_epoch(&self) -> &Vec<EndOfEpochTransactionKind>
pub fn as_end_of_epoch(&self) -> &Vec<EndOfEpochTransactionKind>
Converts this into a end_of_epoch if it is a end_of_epoch variant, or panics otherwise.
pub fn as_end_of_epoch_mut(&mut self) -> &mut Vec<EndOfEpochTransactionKind>
pub fn as_end_of_epoch_mut(&mut self) -> &mut Vec<EndOfEpochTransactionKind>
Converts this into a mut end_of_epoch if it is a end_of_epoch variant, or panics otherwise.
pub fn as_end_of_epoch_opt(&self) -> Option<&Vec<EndOfEpochTransactionKind>>
pub fn as_end_of_epoch_opt(&self) -> Option<&Vec<EndOfEpochTransactionKind>>
Converts this into a end_of_epoch if it is a end_of_epoch variant, or returns None otherwise.
pub fn as_end_of_epoch_mut_opt(
&mut self,
) -> Option<&mut Vec<EndOfEpochTransactionKind>>
pub fn as_end_of_epoch_mut_opt( &mut self, ) -> Option<&mut Vec<EndOfEpochTransactionKind>>
Converts this into a mut end_of_epoch if it is a end_of_epoch variant, or returns None otherwise.
pub fn into_end_of_epoch_opt(self) -> Option<Vec<EndOfEpochTransactionKind>>
pub fn into_end_of_epoch_opt(self) -> Option<Vec<EndOfEpochTransactionKind>>
Converts this into a end_of_epoch if it is a end_of_epoch variant, or returns None otherwise.
pub fn into_end_of_epoch(self) -> Vec<EndOfEpochTransactionKind>
pub fn into_end_of_epoch(self) -> Vec<EndOfEpochTransactionKind>
Converts this into a end_of_epoch if it is a end_of_epoch variant, or panics otherwise.
pub fn new_programmable(tx: ProgrammableTransaction) -> TransactionKind
pub fn new_programmable(tx: ProgrammableTransaction) -> TransactionKind
Create a TransactionKind::Programmable.
pub fn new_genesis(tx: GenesisTransaction) -> TransactionKind
pub fn new_genesis(tx: GenesisTransaction) -> TransactionKind
Create a TransactionKind::Genesis.
pub fn new_consensus_commit_prologue_v1(
tx: ConsensusCommitPrologueV1,
) -> TransactionKind
pub fn new_consensus_commit_prologue_v1( tx: ConsensusCommitPrologueV1, ) -> TransactionKind
pub fn new_end_of_epoch(tx: Vec<EndOfEpochTransactionKind>) -> TransactionKind
pub fn new_end_of_epoch(tx: Vec<EndOfEpochTransactionKind>) -> TransactionKind
Create a TransactionKind::EndOfEpoch.
pub fn new_randomness_state_update(tx: RandomnessStateUpdate) -> TransactionKind
pub fn new_randomness_state_update(tx: RandomnessStateUpdate) -> TransactionKind
Create a TransactionKind::RandomnessStateUpdate.
pub fn num_commands(&self) -> usize
pub fn num_commands(&self) -> usize
Returns the number of commands, or 0 if it is a system transaction.
pub fn num_transactions(&self) -> usize
pub fn num_transactions(&self) -> usize
Returns the number of transactions, or 1 if it is a system transaction.