Struct ChangeEpochV4
pub struct ChangeEpochV4 {
pub epoch: u64,
pub protocol_version: u64,
pub storage_charge: u64,
pub computation_charge: u64,
pub computation_charge_burned: u64,
pub storage_rebate: u64,
pub non_refundable_storage_fee: u64,
pub epoch_start_timestamp_ms: u64,
pub system_packages: Vec<SystemPackage>,
pub eligible_active_validators: Vec<u64>,
pub scores: Vec<u64>,
pub adjust_rewards_by_score: bool,
}Fields
epoch: u64The next (to become) epoch ID.
protocol_version: u64The protocol version in effect in the new epoch.
storage_charge: u64The total amount of gas charged for storage during the epoch.
computation_charge: u64The total amount of gas charged for computation during the epoch.
computation_charge_burned: u64The total amount of gas burned for computation during the epoch.
storage_rebate: u64The amount of storage rebate refunded to the txn senders.
non_refundable_storage_fee: u64The non-refundable storage fee.
epoch_start_timestamp_ms: u64Unix timestamp when epoch started
system_packages: Vec<SystemPackage>System packages (specifically framework and move stdlib) that are written before the new epoch starts. This tracks framework upgrades on chain. When executing the ChangeEpoch txn, the validator must write out the modules below. Modules are provided with the version they will be upgraded to, their modules in serialized form (which include their package ID), and a list of their transitive dependencies.
eligible_active_validators: Vec<u64>Vector of active validator indices eligible to take part in committee selection because they support the new, target protocol version.
scores: Vec<u64>Vector of scores relative to the past epoch performance of each validator, ordered by the past epoch’s validator index.
adjust_rewards_by_score: boolWhether to adjust validator rewards based on score.