MakeMoveVector

Struct MakeMoveVector 

pub struct MakeMoveVector {
    pub type_: Option<TypeTag>,
    pub elements: Vec<Argument>,
}
Command to build a move vector out of a set of individual elements

BCS

The BCS serialized form for this type is defined by the following ABNF:

make-move-vector = (option type-tag) (vector argument)

Fields

type_: Option<TypeTag>

Type of the individual elements

This is required to be set when the type can’t be inferred, for example when the set of provided arguments are all pure input values.

elements: Vec<Argument>

The set individual elements to build the vector with