Struct MergeCoins
pub struct MergeCoins {
pub coin: Argument,
pub coins_to_merge: Vec<Argument>,
}Expand description
Command to merge multiple coins of the same type into a single coin
BCS
The BCS serialized form for this type is defined by the following ABNF:
merge-coins = argument (vector argument)Fields
coin: ArgumentCoin to merge coins into
coins_to_merge: Vec<Argument>Set of coins to merge into coin
All listed coins must be of the same type and be the same type as coin