Struct ProgrammableMoveCall
pub struct ProgrammableMoveCall {
pub package: ObjectId,
pub module: Identifier,
pub function: Identifier,
pub type_arguments: Vec<TypeTag>,
pub arguments: Vec<Argument>,
}Expand description
Command to call a move function
Functions that can be called by a MoveCall command are those that have a
function signature that is either entry or public (which don’t have a
reference return type).
BCS
The BCS serialized form for this type is defined by the following ABNF:
move-call = object-id ; package id
identifier ; module name
identifier ; function name
(vector type-tag) ; type arguments, if any
(vector argument) ; input argumentsFields
package: ObjectIdThe package containing the module and function.
module: IdentifierThe specific module in the package containing the function.
function: IdentifierThe function to be called.
type_arguments: Vec<TypeTag>The type arguments to the function.
arguments: Vec<Argument>The arguments to the function.