pub type SignedTransaction = Envelope<SenderSignedTransaction, AuthoritySignInfo>;Expand description
A transaction that is signed by a sender and also by an authority.
Aliased Type
pub struct SignedTransaction { /* private fields */ }pub type SignedTransaction = Envelope<SenderSignedTransaction, AuthoritySignInfo>;A transaction that is signed by a sender and also by an authority.
pub struct SignedTransaction { /* private fields */ }